Documentation
¶
Overview ¶
Package bind is a precisely modified version of echo's DefaultBinder and the related code from https://raw.githubusercontent.com/labstack/echo/v4.1.13/bind.go
Specific Changes: - lines 36-48 of that file are removed as calling bindData on json payloads breaks binding arrays - long lines are shortened to satisfy the linter, - variables from outside bind.go are imported from the latest echo package
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BindUnmarshaler ¶
type BindUnmarshaler interface {
// UnmarshalParam decodes and assigns a value from an form or query param.
UnmarshalParam(param string) error
}
BindUnmarshaler is the interface used to wrap the UnmarshalParam method. Types that don't implement this, but do implement encoding.TextUnmarshaler will use that interface instead.
type DefaultBinder ¶
type DefaultBinder struct{}
DefaultBinder is the default implementation of the Binder interface.
Click to show internal directories.
Click to hide internal directories.