Documentation
¶
Index ¶
- func ListNotifications(notificationCodes []notifications.NotificationType) models.HandlerFunc
- func RegisterInfo(r *models.Router, bc models.BuildConfig, mids ...models.Middleware)
- func RegisterMonitoring(r *models.Router, mids ...models.Middleware)
- func RegisterNotification(r *models.Router, notificationCodes []notifications.NotificationType, ...)
- type Build
- type Caller
- type Information
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ListNotifications ¶
func ListNotifications(notificationCodes []notifications.NotificationType) models.HandlerFunc
ListNotifications simply returns the set of notification codes used by the component
func RegisterInfo ¶
func RegisterInfo(r *models.Router, bc models.BuildConfig, mids ...models.Middleware)
RegisterInfo registers the identity endpoints to the provided group
func RegisterMonitoring ¶
func RegisterMonitoring(r *models.Router, mids ...models.Middleware)
RegisterMonitoring registers the prometheus monitoring endpoints
func RegisterNotification ¶
func RegisterNotification(r *models.Router, notificationCodes []notifications.NotificationType, mids ...models.Middleware)
RegisterNotification registers the endpoint required by notification-component to pull
notification codes from all other components
Types ¶
type Build ¶
type Build struct {
Version string `json:"version"`
ReleaseTimestamp string `json:"release_timestamp"`
Build string `json:"build"`
EMFVersion string `json:"emf_version"`
EchoVersion string `json:"echo_version"`
}
Build represents the versioning and time stamp for the binary run by the component.
type Caller ¶
type Caller struct {
RequestID string `json:"request_id"`
RemoteAddr string `json:"remote_addr"`
RequestURI string `json:"request_uri"`
Referer string `json:"referer"`
UserAgent string `json:"user_agent"`
}
Caller contains relevant information about a request.
type Information ¶
type Information struct {
CurrentTime time.Time `json:"current_time"`
ComponentName string `json:"component_name"`
APIPort string `json:"api_port"`
Build Build `json:"build"`
Caller Caller `json:"caller"`
AdditionalInformation []models.DataPoint `json:"additional_information"`
}
Information encapusaltes relevant information about the running component and the client request.
Click to show internal directories.
Click to hide internal directories.